@@ -14,8 +14,7 @@
  *                                                                             *
  *******************************************************************************
  */
-void Interrupt(int ply)
-{
+void Interrupt(int ply) {
   int temp, i, left = 0, readstat, result, time_used;
   int save_move_number;
   TREE *const tree = block[0];
@@ -55,10 +54,10 @@ void Interrupt(int ply)
         save_move_number = move_number;
         if (!wtm)
           move_number--;
-        if (wtm)
-          Print(128, "White(%d): %s\n", move_number, buffer);
-        else
+        if (root_wtm)
           Print(128, "Black(%d): %s\n", move_number, buffer);
+        else
+          Print(128, "White(%d): %s\n", move_number, buffer);
         move_number = save_move_number;
       }
 /*
