@@ -12,8 +12,7 @@
  *                                                                             *
  *******************************************************************************
  */
-int NextEvasion(TREE * RESTRICT tree, int ply, int wtm)
-{
+int NextEvasion(TREE * RESTRICT tree, int ply, int wtm) {
   register int *movep, *sortv, moves = 0;
 
   switch (tree->next_status[ply].phase) {
@@ -27,17 +26,17 @@ int NextEvasion(TREE * RESTRICT tree, int ply, int wtm)
  *                                                          *
  ************************************************************
  */
-  case HASH_MOVE:
-    if (tree->hash_move[ply]) {
-      tree->next_status[ply].phase = SORT_ALL_MOVES;
-      tree->curmv[ply] = tree->hash_move[ply];
-      if (ValidMove(tree, ply, wtm, tree->curmv[ply]))
-        return (HASH_MOVE);
+    case HASH_MOVE:
+      if (tree->hash_move[ply]) {
+        tree->next_status[ply].phase = SORT_ALL_MOVES;
+        tree->curmv[ply] = tree->hash_move[ply];
+        if (ValidMove(tree, ply, wtm, tree->curmv[ply]))
+          return (HASH_MOVE);
 #if defined(DEBUG)
-      else
-        Print(128, "bad move from hash table, ply=%d\n", ply);
+        else
+          Print(128, "bad move from hash table, ply=%d\n", ply);
 #endif
-    }
+      }
 /*
  ************************************************************
  *                                                          *
@@ -56,25 +55,27 @@ int NextEvasion(TREE * RESTRICT tree, int ply, int wtm)
  *                                                          *
  ************************************************************
  */
-  case SORT_ALL_MOVES:
-    tree->last[ply] =
-        GenerateCheckEvasions(tree, ply, wtm, tree->last[ply - 1]);
-    tree->next_status[ply].phase = REMAINING_MOVES;
-    for (movep = tree->last[ply - 1], sortv = tree->sort_value;
-        movep < tree->last[ply]; moves++, movep++, sortv++)
-      if (tree->hash_move[ply] && *movep == tree->hash_move[ply]) {
-        *sortv = -999999;
-        *movep = 0;
-      } else {
-        if (pc_values[Piece(*movep)] < pc_values[Captured(*movep)])
-          *sortv = 128 * pc_values[Captured(*movep)] - pc_values[Piece(*movep)];
-        else {
-          *sortv = Swap(tree, From(*movep), To(*movep), wtm);
-          if (*sortv >= 0)
+    case SORT_ALL_MOVES:
+      tree->last[ply] =
+          GenerateCheckEvasions(tree, ply, wtm, tree->last[ply - 1]);
+      tree->next_status[ply].phase = REMAINING_MOVES;
+      for (movep = tree->last[ply - 1], sortv = tree->sort_value;
+          movep < tree->last[ply]; moves++, movep++, sortv++)
+        if (tree->hash_move[ply] && *movep == tree->hash_move[ply]) {
+          *sortv = -999999;
+          *movep = 0;
+        } else {
+          if (pc_values[Piece(*movep)] <= pc_values[Captured(*movep)])
             *sortv =
                 128 * pc_values[Captured(*movep)] - pc_values[Piece(*movep)];
+          else {
+            *sortv = Swap(tree, *movep, wtm);
+            if (*sortv >= 0)
+              *sortv =
+                  128 * pc_values[Captured(*movep)] -
+                  pc_values[Piece(*movep)];
+          }
         }
-      }
 /*
  ************************************************************
  *                                                          *
@@ -85,26 +86,26 @@ int NextEvasion(TREE * RESTRICT tree, int ply, int wtm)
  *                                                          *
  ************************************************************
  */
-    if (tree->last[ply] > tree->last[ply - 1] + 1) {
-      register int done, temp;
-      register int *end = tree->last[ply - 1] + moves - 1;
+      if (tree->last[ply] > tree->last[ply - 1] + 1) {
+        register int done, temp;
+        register int *end = tree->last[ply - 1] + moves - 1;
 
-      do {
-        done = 1;
-        sortv = tree->sort_value;
-        for (movep = tree->last[ply - 1]; movep < end; movep++, sortv++)
-          if (*sortv < *(sortv + 1)) {
-            temp = *sortv;
-            *sortv = *(sortv + 1);
-            *(sortv + 1) = temp;
-            temp = *movep;
-            *movep = *(movep + 1);
-            *(movep + 1) = temp;
-            done = 0;
-          }
-      } while (!done);
-    }
-    tree->next_status[ply].last = tree->last[ply - 1];
+        do {
+          done = 1;
+          sortv = tree->sort_value;
+          for (movep = tree->last[ply - 1]; movep < end; movep++, sortv++)
+            if (*sortv < *(sortv + 1)) {
+              temp = *sortv;
+              *sortv = *(sortv + 1);
+              *(sortv + 1) = temp;
+              temp = *movep;
+              *movep = *(movep + 1);
+              *(movep + 1) = temp;
+              done = 0;
+            }
+        } while (!done);
+      }
+      tree->next_status[ply].last = tree->last[ply - 1];
 /*
  ************************************************************
  *                                                          *
@@ -112,22 +113,22 @@ int NextEvasion(TREE * RESTRICT tree, int ply, int wtm)
  *                                                          *
  ************************************************************
  */
-  case REMAINING_MOVES:
-    for (; tree->next_status[ply].last < tree->last[ply];
-        tree->next_status[ply].last++)
-      if ((*tree->next_status[ply].last)) {
-        tree->curmv[ply] = *tree->next_status[ply].last++;
-        return (REMAINING_MOVES);
-      }
-    return (NONE);
-  default:
-    printf("oops!  next_status.phase is bad! [evasion %d]\n",
-        tree->next_status[ply].phase);
+    case REMAINING_MOVES:
+      for (; tree->next_status[ply].last < tree->last[ply];
+          tree->next_status[ply].last++)
+        if ((*tree->next_status[ply].last)) {
+          tree->curmv[ply] = *tree->next_status[ply].last++;
+          return (REMAINING_MOVES);
+        }
+      return (NONE);
+    default:
+      printf("oops!  next_status.phase is bad! [evasion %d]\n",
+          tree->next_status[ply].phase);
   }
   return (NONE);
 }
 
-/* last modified 01/14/09 */
+/* last modified 07/24/09 */
 /*
  *******************************************************************************
  *                                                                             *
@@ -135,8 +136,7 @@ int NextEvasion(TREE * RESTRICT tree, int ply, int wtm)
  *                                                                             *
  *******************************************************************************
  */
-int NextMove(TREE * RESTRICT tree, int ply, int wtm)
-{
+int NextMove(TREE * RESTRICT tree, int ply, int wtm) {
   register int *movep, *sortv;
 
   switch (tree->next_status[ply].phase) {
@@ -149,54 +149,44 @@ int NextMove(TREE * RESTRICT tree, int ply, int wtm)
  *                                                          *
  ************************************************************
  */
-  case HASH_MOVE:
-    tree->next_status[ply].phase = GENERATE_CAPTURE_MOVES;
-    if (tree->hash_move[ply]) {
-      tree->curmv[ply] = tree->hash_move[ply];
-      if (ValidMove(tree, ply, wtm, tree->curmv[ply]))
-        return (HASH_MOVE);
+    case HASH_MOVE:
+      tree->next_status[ply].phase = GENERATE_CAPTURE_MOVES;
+      if (tree->hash_move[ply]) {
+        tree->curmv[ply] = tree->hash_move[ply];
+        if (ValidMove(tree, ply, wtm, tree->curmv[ply]))
+          return (HASH_MOVE);
 #if defined(DEBUG)
-      else
-        Print(128, "bad move from hash table, ply=%d\n", ply);
+        else
+          Print(128, "bad move from hash table, ply=%d\n", ply);
 #endif
-    }
+      }
 /*
  ************************************************************
  *                                                          *
- *   Generate captures and sort them based on whether they  *
- *   are safe according to SEE (swap()) analysis or not.    *
- *   If they are unsafe, they are sorted to the bottom of   *
- *   the capture list, otherwise moves are sorted by using  *
- *   MVV/LVA ordering so that we capture the most valuable  *
- *   piece first, which reduces the size of the tree below  *
- *   this node when a piece (often the queen) with lots of  *
- *   potential moves is removed.                            *
+ *   Generate captures and sort them based on the simple    *
+ *   MVV/LVA ordering where we try to capture the most      *
+ *   valuable victim piece possible, using the least        *
+ *   valuable attacking piece possible.  Later we will test *
+ *   to see if the capture appears to lose material and we  *
+ *   will defer searching it until later.                   *
  *                                                          *
  ************************************************************
  */
-  case GENERATE_CAPTURE_MOVES:
-    tree->next_status[ply].phase = CAPTURE_MOVES;
-    tree->last[ply] = GenerateCaptures(tree, ply, wtm, tree->last[ply - 1]);
-    tree->next_status[ply].remaining = 0;
-    for (movep = tree->last[ply - 1], sortv = tree->sort_value;
-        movep < tree->last[ply]; movep++, sortv++)
-      if (tree->hash_move[ply] && *movep == tree->hash_move[ply]) {
-        *sortv = -999999;
-        *movep = 0;
-        tree->hash_move[ply] = 0;
-      } else {
-        if (pc_values[Piece(*movep)] < pc_values[Captured(*movep)]) {
-          *sortv = 128 * pc_values[Captured(*movep)] - pc_values[Piece(*movep)];
-          tree->next_status[ply].remaining++;
+    case GENERATE_CAPTURE_MOVES:
+      tree->next_status[ply].phase = CAPTURE_MOVES;
+      tree->last[ply] = GenerateCaptures(tree, ply, wtm, tree->last[ply - 1]);
+      tree->next_status[ply].remaining = 0;
+      for (movep = tree->last[ply - 1], sortv = tree->sort_value;
+          movep < tree->last[ply]; movep++, sortv++)
+        if (tree->hash_move[ply] && *movep == tree->hash_move[ply]) {
+          *sortv = -999999;
+          *movep = 0;
+          tree->hash_move[ply] = 0;
         } else {
-          *sortv = Swap(tree, From(*movep), To(*movep), wtm);
-          if (*sortv >= 0) {
-            *sortv =
-                128 * pc_values[Captured(*movep)] - pc_values[Piece(*movep)];
-            tree->next_status[ply].remaining++;
-          }
+          *sortv =
+              128 * pc_values[Captured(*movep)] - pc_values[Piece(*movep)];
+          tree->next_status[ply].remaining++;
         }
-      }
 /*
  ************************************************************
  *                                                          *
@@ -206,28 +196,28 @@ int NextMove(TREE * RESTRICT tree, int ply, int wtm)
  *                                                          *
  ************************************************************
  */
-    if (tree->last[ply] > tree->last[ply - 1] + 1) {
-      int temp1, temp2, *tmovep, *tsortv;
-      int *end;
+      if (tree->last[ply] > tree->last[ply - 1] + 1) {
+        int temp1, temp2, *tmovep, *tsortv;
+        int *end;
 
-      sortv = tree->sort_value + 1;
-      end = tree->last[ply];
-      for (movep = tree->last[ply - 1] + 1; movep < end; movep++, sortv++) {
-        temp1 = *movep;
-        temp2 = *sortv;
-        tmovep = movep - 1;
-        tsortv = sortv - 1;
-        while (tmovep >= tree->last[ply - 1] && *tsortv < temp2) {
-          *(tsortv + 1) = *tsortv;
-          *(tmovep + 1) = *tmovep;
-          tmovep--;
-          tsortv--;
+        sortv = tree->sort_value + 1;
+        end = tree->last[ply];
+        for (movep = tree->last[ply - 1] + 1; movep < end; movep++, sortv++) {
+          temp1 = *movep;
+          temp2 = *sortv;
+          tmovep = movep - 1;
+          tsortv = sortv - 1;
+          while (tmovep >= tree->last[ply - 1] && *tsortv < temp2) {
+            *(tsortv + 1) = *tsortv;
+            *(tmovep + 1) = *tmovep;
+            tmovep--;
+            tsortv--;
+          }
+          *(tmovep + 1) = temp1;
+          *(tsortv + 1) = temp2;
         }
-        *(tmovep + 1) = temp1;
-        *(tsortv + 1) = temp2;
       }
-    }
-    tree->next_status[ply].last = tree->last[ply - 1];
+      tree->next_status[ply].last = tree->last[ply - 1];
 /*
  ************************************************************
  *                                                          *
@@ -237,16 +227,20 @@ int NextMove(TREE * RESTRICT tree, int ply, int wtm)
  *                                                          *
  ************************************************************
  */
-  case CAPTURE_MOVES:
-    if (tree->next_status[ply].remaining) {
-      tree->curmv[ply] = *(tree->next_status[ply].last);
-      *tree->next_status[ply].last++ = 0;
-      tree->next_status[ply].remaining--;
-      if (!tree->next_status[ply].remaining)
-        tree->next_status[ply].phase = KILLER_MOVE_1;
-      return (CAPTURE_MOVES);
-    }
-    tree->next_status[ply].phase = KILLER_MOVE_1;
+    case CAPTURE_MOVES:
+      while (tree->next_status[ply].remaining) {
+        tree->curmv[ply] = *(tree->next_status[ply].last++);
+        tree->next_status[ply].remaining--;
+        if (!tree->next_status[ply].remaining)
+          tree->next_status[ply].phase = KILLER_MOVE_1;
+        if (pc_values[Piece(tree->curmv[ply])] >
+            pc_values[Captured(tree->curmv[ply])] &&
+            Swap(tree, tree->curmv[ply], wtm) < 0)
+          continue;
+        *(tree->next_status[ply].last - 1) = 0;
+        return (CAPTURE_MOVES);
+      }
+      tree->next_status[ply].phase = KILLER_MOVE_1;
 /*
  ************************************************************
  *                                                          *
@@ -256,21 +250,21 @@ int NextMove(TREE * RESTRICT tree, int ply, int wtm)
  *                                                          *
  ************************************************************
  */
-  case KILLER_MOVE_1:
-    if ((tree->hash_move[ply] != tree->killers[ply].move1) &&
-        ValidMove(tree, ply, wtm, tree->killers[ply].move1)) {
-      tree->curmv[ply] = tree->killers[ply].move1;
-      tree->next_status[ply].phase = KILLER_MOVE_2;
-      return (KILLER_MOVE_1);
-    }
-  case KILLER_MOVE_2:
-    if ((tree->hash_move[ply] != tree->killers[ply].move2) &&
-        ValidMove(tree, ply, wtm, tree->killers[ply].move2)) {
-      tree->curmv[ply] = tree->killers[ply].move2;
+    case KILLER_MOVE_1:
+      if ((tree->hash_move[ply] != tree->killers[ply].move1) &&
+          ValidMove(tree, ply, wtm, tree->killers[ply].move1)) {
+        tree->curmv[ply] = tree->killers[ply].move1;
+        tree->next_status[ply].phase = KILLER_MOVE_2;
+        return (KILLER_MOVE_1);
+      }
+    case KILLER_MOVE_2:
+      if ((tree->hash_move[ply] != tree->killers[ply].move2) &&
+          ValidMove(tree, ply, wtm, tree->killers[ply].move2)) {
+        tree->curmv[ply] = tree->killers[ply].move2;
+        tree->next_status[ply].phase = GENERATE_ALL_MOVES;
+        return (KILLER_MOVE_2);
+      }
       tree->next_status[ply].phase = GENERATE_ALL_MOVES;
-      return (KILLER_MOVE_2);
-    }
-    tree->next_status[ply].phase = GENERATE_ALL_MOVES;
 /*
  ************************************************************
  *                                                          *
@@ -278,10 +272,10 @@ int NextMove(TREE * RESTRICT tree, int ply, int wtm)
  *                                                          *
  ************************************************************
  */
-  case GENERATE_ALL_MOVES:
-    tree->last[ply] = GenerateNoncaptures(tree, ply, wtm, tree->last[ply]);
-    tree->next_status[ply].phase = REMAINING_MOVES;
-    tree->next_status[ply].last = tree->last[ply - 1];
+    case GENERATE_ALL_MOVES:
+      tree->last[ply] = GenerateNoncaptures(tree, ply, wtm, tree->last[ply]);
+      tree->next_status[ply].phase = REMAINING_MOVES;
+      tree->next_status[ply].last = tree->last[ply - 1];
 /*
  ************************************************************
  *                                                          *
@@ -289,18 +283,21 @@ int NextMove(TREE * RESTRICT tree, int ply, int wtm)
  *                                                          *
  ************************************************************
  */
-  case REMAINING_MOVES:
-    for (; tree->next_status[ply].last < tree->last[ply];
-        tree->next_status[ply].last++)
-      if (*tree->next_status[ply].last) {
-        tree->curmv[ply] = *tree->next_status[ply].last;
-        *tree->next_status[ply].last++ = 0;
-        return (REMAINING_MOVES);
-      }
-    return (NONE);
-  default:
-    Print(4095, "oops!  next_status.phase is bad! [normal %d]\n",
-        tree->next_status[ply].phase);
+    case REMAINING_MOVES:
+      for (; tree->next_status[ply].last < tree->last[ply];
+          tree->next_status[ply].last++)
+        if (*tree->next_status[ply].last &&
+            *tree->next_status[ply].last != tree->hash_move[ply] &&
+            *tree->next_status[ply].last != tree->killers[ply].move1 &&
+            *tree->next_status[ply].last != tree->killers[ply].move2) {
+          tree->curmv[ply] = *tree->next_status[ply].last;
+          *tree->next_status[ply].last++ = 0;
+          return (REMAINING_MOVES);
+        }
+      return (NONE);
+    default:
+      Print(4095, "oops!  next_status.phase is bad! [normal %d]\n",
+          tree->next_status[ply].phase);
   }
   return (NONE);
 }
@@ -313,8 +310,7 @@ int NextMove(TREE * RESTRICT tree, int ply, int wtm)
  *                                                                             *
  *******************************************************************************
  */
-int NextRootMove(TREE * RESTRICT tree, TREE * RESTRICT mytree, int wtm)
-{
+int NextRootMove(TREE * RESTRICT tree, TREE * RESTRICT mytree, int wtm) {
   register int done, which, i;
   BITBOARD total_nodes;
 
@@ -387,14 +383,17 @@ int NextRootMove(TREE * RESTRICT tree, TREE * RESTRICT mytree, int wtm)
  */
       if ((tree->nodes_searched > noise_level) && (display_options & 32)) {
         Lock(lock_io);
-        sprintf(mytree->remaining_moves_text, "%d/%d", which + 1, n_root_moves);
+        sprintf(mytree->remaining_moves_text, "%d/%d", which + 1,
+            n_root_moves);
         end_time = ReadClock();
         if (pondering)
           printf("               %2i   %s%7s?  ", iteration_depth,
-              DisplayTime(end_time - start_time), mytree->remaining_moves_text);
+              DisplayTime(end_time - start_time),
+              mytree->remaining_moves_text);
         else
           printf("               %2i   %s%7s*  ", iteration_depth,
-              DisplayTime(end_time - start_time), mytree->remaining_moves_text);
+              DisplayTime(end_time - start_time),
+              mytree->remaining_moves_text);
         if (display_options & 32 && display_options & 64)
           printf("%d. ", move_number);
         if ((display_options & 32) && (display_options & 64) && Flip(wtm))
@@ -414,7 +413,19 @@ int NextRootMove(TREE * RESTRICT tree, TREE * RESTRICT mytree, int wtm)
         fflush(stdout);
         Unlock(lock_io);
       }
-      if (!(root_moves[which].status & 128))
+/*
+ ************************************************************
+ *                                                          *
+ *   Bit of a tricky exit.  If the move is flagged as "do   *
+ *   not reduce" or "do not search in parallel" then we     *
+ *   return "HASH_MOVE" which will prevent SearchRoot()     *
+ *   from reducing the move (LMR).  Otherwise we return the *
+ *   more common "REMAINING_MOVES" value which allows LMR   *
+ *   to be used on those root moves.                        *
+ *                                                          *
+ ************************************************************
+ */
+      if (root_moves[which].status & 0xc0)
         return (HASH_MOVE);
       else
         return (REMAINING_MOVES);
@@ -443,8 +454,7 @@ int NextRootMove(TREE * RESTRICT tree, TREE * RESTRICT mytree, int wtm)
  *                                                                             *
  *******************************************************************************
  */
-int NextRootMoveParallel(void)
-{
+int NextRootMoveParallel(void) {
   register int which;
 
 /*
